summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/irc/libkirc/kircentity.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/irc/libkirc/kircentity.h')
-rw-r--r--kopete/protocols/irc/libkirc/kircentity.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/kopete/protocols/irc/libkirc/kircentity.h b/kopete/protocols/irc/libkirc/kircentity.h
index c9336439..d802d8f4 100644
--- a/kopete/protocols/irc/libkirc/kircentity.h
+++ b/kopete/protocols/irc/libkirc/kircentity.h
@@ -22,10 +22,10 @@
#include <kresolver.h>
#include <ksharedptr.h>
-#include <qobject.h>
-#include <qregexp.h>
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <tqobject.h>
+#include <tqregexp.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
namespace KIRC
{
@@ -33,7 +33,7 @@ namespace KIRC
class Engine;
class Entity
- : public QObject,
+ : public TQObject,
public KShared
{
Q_OBJECT
@@ -48,49 +48,49 @@ public:
User
};
- Entity(const QString &name, const Type type = Unknown);
+ Entity(const TQString &name, const Type type = Unknown);
virtual ~Entity();
- QString name() const;
- QString host() const;
+ TQString name() const;
+ TQString host() const;
KIRC::Entity::Type type() const;
KIRC::Entity::Type guessType();
- static KIRC::Entity::Type guessType(const QString &name);
+ static KIRC::Entity::Type guessType(const TQString &name);
- // FIXME: Remove these is* functions ... They are duplicate with the ::guessType(const QString&)
- inline static bool isUser( const QString &s )
+ // FIXME: Remove these is* functions ... They are duplicate with the ::guessType(const TQString&)
+ inline static bool isUser( const TQString &s )
{ return sm_userRegExp.exactMatch(s); };
inline bool isChannel()
{ return isChannel(m_name); };
- inline static bool isChannel( const QString &s )
+ inline static bool isChannel( const TQString &s )
{ return sm_channelRegExp.exactMatch(s); };
- QString userNick() const;
- static QString userNick(const QString &s);
+ TQString userNick() const;
+ static TQString userNick(const TQString &s);
- QString userName() const;
- static QString userName(const QString &s);
+ TQString userName() const;
+ static TQString userName(const TQString &s);
- QString userHost() const;
- static QString userHost(const QString &s);
+ TQString userHost() const;
+ static TQString userHost(const TQString &s);
signals:
void destroyed(KIRC::Entity *self);
private:
- static QString userInfo(const QString &s, int num_cap);
+ static TQString userInfo(const TQString &s, int num_cap);
- static const QRegExp sm_userRegExp;
- static const QRegExp sm_userStrictRegExp;
- static const QRegExp sm_channelRegExp;
+ static const TQRegExp sm_userRegExp;
+ static const TQRegExp sm_userStrictRegExp;
+ static const TQRegExp sm_channelRegExp;
KIRC::Entity::Type m_type;
QString m_name;
// peer ip address if the entity is a User.
- QString m_address;
+ TQString m_address;
};
class EntityPtr
@@ -107,7 +107,7 @@ public:
};
class EntityPtrList
- : public QValueList<EntityPtr>
+ : public TQValueList<EntityPtr>
{
public:
EntityPtrList()
@@ -118,8 +118,8 @@ public:
append(entity);
}
- EntityPtrList(const QValueList<EntityPtr> &list)
- : QValueList<EntityPtr>(list)
+ EntityPtrList(const TQValueList<EntityPtr> &list)
+ : TQValueList<EntityPtr>(list)
{ }
};